@@ -48,7 +48,14 @@ class MorelloTest(Test):
 
 
 class MorelloAndroidTest(MorelloTest):
-    device = "fvp-morello-android"
+    devices = ["fvp-morello-android"]
+
+
+class MorelloBusyBoxPureCap(MorelloTest):
+    devices = ["fvp-morello-busybox"]
+    template = "morello-busybox-purecap.yaml.jinja2"
+    name = "purecap"
+    timeout = 5
 
 
 class MorelloBinder(MorelloAndroidTest):
@@ -102,7 +109,7 @@ class MorelloDvfs(MorelloAndroidTest):
 class MorelloFWTS(MorelloTest):
     name = "fwts"
     timeout = 120
-    device = "fvp-morello-oe"
+    devices = ["fvp-morello-oe"]
     template = "fwts.yaml.jinja2"
     need_test_definition = True
 
